declare type NumberTuple = [number, number];
interface Breakpoints {
    smallOnly: number;
    mediumOnly: NumberTuple;
    largeOnly: NumberTuple;
    xlargeOnly: NumberTuple;
    medium: number;
    large: number;
    xlarge: number;
    xxlarge: number;
}
declare type BreakpointTypes = keyof Breakpoints;
declare const breakPoints: Breakpoints;
declare type MergeBreakpoints = (breakPoints: Record<string, unknown>) => Breakpoints;
declare const mergeBreakpoints: MergeBreakpoints;

declare type LowercaseCharacter = 'a' | 'b' | 'c' | 'd' | 'e' | 'f' | 'g' | 'h' | 'i' | 'j' | 'k' | 'l' | 'm' | 'n' | 'o' | 'p' | 'q' | 'r' | 's' | 't' | 'u' | 'v' | 'w' | 'x' | 'y' | 'z';
declare type AllCharacter = LowercaseCharacter | Uppercase<LowercaseCharacter>;
declare type NonEmptyString = `${AllCharacter}${string}`;
declare type CSSCustomProperties = `var(--${NonEmptyString})`;
declare type LengthUnit = 'vmin' | 'vmax' | 'vh' | 'vw' | '%' | 'ch' | 'ex' | 'em' | 'rem' | 'in' | 'cm' | 'mm' | 'pt' | 'pc' | 'px';
declare type CSSLength = `${number}${LengthUnit}` | CSSCustomProperties;
declare function checkIsCSSLength(string_: string): string_ is CSSLength;

declare type DefaultTheme = Record<string, any>;
declare type BaseTheme = Record<string, CSSLength | string | number>;

declare type Maybe<T> = T | undefined;
declare function fromEntries<T>(entries: Array<[s: string, value: T]>): Record<string, T>;

interface Spacing {
    none: CSSLength;
    xxs: CSSLength;
    xs: CSSLength;
    sm: CSSLength;
    md: CSSLength;
    lg: CSSLength;
    xl: CSSLength;
    xxl: CSSLength;
    xxxl: CSSLength;
    xxxxl: CSSLength;
    xxxxxl: CSSLength;
}
declare type ThemeOrDefaultSpace<T> = T extends {
    space: BaseTheme;
} ? T['space'] : T extends {
    spacing: BaseTheme;
} ? T['spacing'] : Spacing;
declare type SpacingOptions = ThemeOrDefaultSpace<DefaultTheme>;
declare const spacing: Record<string, CSSLength>;
declare type GetSpacingValue = <T>(theme: T & {
    spacing?: BaseTheme;
    space?: BaseTheme;
}, spacingKey: keyof Spacing | keyof SpacingOptions) => Maybe<CSSLength>;
declare const getSpacingValue: GetSpacingValue;

declare type Gutter = CSSLength | number | keyof SpacingOptions;
declare function getSafeGutter<T extends BaseTheme>(theme: T, gutter?: Gutter): Maybe<CSSLength>;
declare function validateGutter<T extends {
    gutter?: Gutter;
}>({ gutter }: T, propName: string): void;

interface Sizes {
    xxsmall: CSSLength;
    xsmall: CSSLength;
    small: CSSLength;
    medium: CSSLength;
    large: CSSLength;
    xlarge: CSSLength;
    xxlarge: CSSLength;
}
declare type ThemeOrDefaultSizes<T> = T extends {
    sizes: BaseTheme;
} ? T['sizes'] : Sizes;
declare type SizeOptions = ThemeOrDefaultSizes<DefaultTheme>;
declare const sizes: Sizes;
declare type GetSizeValue = <T>(theme: T & {
    sizes?: BaseTheme;
}, sizingKey: unknown) => Maybe<CSSLength>;
declare const getSizeValue: GetSizeValue;

declare function uid(prefix?: string): string;

export { BaseTheme, BreakpointTypes, Breakpoints, CSSLength, DefaultTheme, Gutter, Maybe, SizeOptions, Sizes, Spacing, SpacingOptions, breakPoints, checkIsCSSLength, fromEntries, getSafeGutter, getSizeValue, getSpacingValue, mergeBreakpoints, sizes, spacing, uid, validateGutter };
